@@ -6,9 +6,13 @@ import math
 import os
 import sys
 import time
-from configparser import SafeConfigParser
 from numbers import Number
 
+try:
+    from ConfigParser import SafeConfigParser as ConfigParser
+except ImportError:
+    from configparser import ConfigParser
+
 import six
 
 from .base import SquirroClient
@@ -304,7 +308,7 @@ class ItemUploader(object):
     def _load_config(self, kwargs):
         """Loads the configuration from file and merges it with the passed-in
         arguments"""
-        parser = SafeConfigParser()
+        parser = ConfigParser()
         file_names = kwargs.get("config_file")
         if not file_names:
             file_names = [os.path.expanduser("~/.squirrorc")]
