@@ -208,6 +208,91 @@ class TopicApiBaseMixin:
         res = self._perform_request("post", url, data=json.dumps(data), headers=headers)
         return self._process_response(res)
 
+    def query_for_you(
+        self,
+        project_id: str,
+        query: Optional[str] = None,
+        query_context: Optional[Dict[str, Optional[str]]] = None,
+        aggregations=None,
+        start=None,
+        count=None,
+        fields=None,
+        highlight=None,
+        next_params=None,
+        created_before=None,
+        created_after=None,
+        options=None,
+        encrypted_query=None,
+        child_count=None,
+        timing: bool = False,
+        **kwargs,
+    ):
+        """Wraps the `query` endpoint and adds an additional user-behaviour centric view on the data.
+
+        It allows to easily:
+            - search only within last read items by the user
+            - search only within top trending items on the project (tbd)
+
+        **Experimental - likely to be changed in the future!**
+
+        :param kwargs: The endpoint supports the same arguments as the `query` endpoint (except pagination).
+
+        :returns: Matching query items annoted with `item_read` metadata & sorted DESC by user-read-time:
+
+                - item_read.last_read_by_user  : timestamp of last item.read event (by user)
+                - item_read.read_count_by_user : amount of item.read events (by user)
+
+        Example::
+
+            >>> client.query_for_you(project_id=f"{project_id}", count=1, fields=["title"])
+
+            {
+            'count': 1,
+            'items': [
+                {'id': 'z9CNx-NMK5ZwCGpg5FrqUw',
+                'title': 'Climate change accelerates',
+                'sources': [{'id': 'Y2zh9RFbTVqG2hBmuoATNQ', 'title': 'CSV'}],
+                'item_read': {
+                    'last_read_by_user': '2022-07-04T15:58:24',
+                    'read_count_by_user': 3
+                },
+                'read': True
+            }]}
+
+        """
+
+        url = f"{self.topic_api_url}/{self.version}/{self.tenant}/projects/{project_id}/items/query_for_you"
+
+        headers = {"Content-Type": "application/json"}
+
+        args = {
+            "query": query,
+            "query_context": query_context,
+            "aggregations": aggregations,
+            "start": start,
+            "count": count,
+            "child_count": child_count,
+            "fields": fields,
+            "highlight": highlight,
+            "next_params": next_params,
+            "options": options,
+            "created_before": created_before,
+            "created_after": created_after,
+            "encrypted_query": encrypted_query,
+            "timing": "true" if timing else None,  # timing parameter expects a str
+        }
+        if "scroll" in kwargs:
+            logging.warning(
+                "Wrong usage of `scroll` parameter! Has no effect for `query` method since v3.3.8. "
+                "Use `scan` method to perform scrolling."
+            )
+            kwargs.pop("scroll")
+        args.update(kwargs)
+        data = {k: v for k, v in list(args.items()) if v is not None}
+
+        res = self._perform_request("post", url, data=json.dumps(data), headers=headers)
+        return self._process_response(res)
+
     def query(
         self,
         project_id: str,
