@@ -53,7 +53,9 @@ class MachineLearningMixin:
             path
         :param type: Optional parameter to define type of the Machine
             learning workflow. Possible values are `other`, `query`, `query_default`,
-            `ais`, `published`. If not specified, the default type is `other`.
+            `ais`, `published`, `document_embedder_queries`,
+            `document_embedder_queries_default`. If not specified, the default type is
+            `other`.
         """
         base_url = "{}/v0/{}/projects/{}/machinelearning_workflows"
         headers = {"Content-Type": "application/json"}
@@ -152,7 +154,9 @@ class MachineLearningMixin:
             path.
         :param type: Optional parameter to define type of the Machine
             learning workflow. Possible values are `other`, `query`, `query_default`,
-            `ais`, `published`. If not specified, the default type is `other`.
+            `ais`, `published`, `document_embedder_queries`,
+            `document_embedder_queries_default`. If not specified, the default type is
+            `other`.
         """
         base_url = "{}/v0/{}/projects/{}/machinelearning_workflows"
         headers = {"Content-Type": "application/json"}
@@ -246,8 +250,9 @@ class MachineLearningMixin:
             specified, the name of the workflow will be the same as the original one.
         :param type: Optional parameter to define type of the Machine
             learning workflow. Possible values are `other`, `query`, `query_default`,
-            `ais`, `published`. If not specified, the type of the workflow will be the
-            same as the original one.
+            `ais`, `published`, `document_embedder_queries`,
+            `document_embedder_queries_default`. If not specified, the type of the
+            workflow will be the same as the original one.
         """
         url = (
             f"{self.topic_api_url}/v0/{self.tenant}/projects/{project_id}"
