@@ -4,7 +4,7 @@ from typing import Optional
 from squirro_client.util import _clean_params, deprecation
 
 
-class SourcesMixin(object):
+class SourcesMixin:
     def get_sources(
         self,
         project_id: str,
@@ -299,6 +299,7 @@ class SourcesMixin(object):
         paused=False,
         use_default_options=None,
         notify_scheduler=None,
+        priority=None,
     ):
         """Create a new source.
 
@@ -325,6 +326,7 @@ class SourcesMixin(object):
         :param notify_scheduler: Optional boolean. Indicate whether or not to notify
             the scheduler to immediately start the procedure of loading data from the
             source.
+        :param priority: Optional string parameter to define the priority for the source.
         :returns: A dictionary which contains the new source.
 
         Example::
@@ -394,6 +396,8 @@ class SourcesMixin(object):
             data["use_default_options"] = use_default_options
         if notify_scheduler is not None:
             data["notify_scheduler"] = notify_scheduler
+        if priority is not None:
+            data["priority"] = priority
 
         res = self._perform_request("post", url, data=json.dumps(data), headers=headers)
         return self._process_response(res, [200, 201])
@@ -410,6 +414,7 @@ class SourcesMixin(object):
         validate_schema=None,
         notify_scheduler=None,
         execute_rerun=None,
+        priority=None,
     ):
         """Modify an existing source.
 
@@ -431,6 +436,7 @@ class SourcesMixin(object):
             source.
         :param execute_rerun: Optional boolean. Indicate whether or not to queue for
             reprocessing the batches (if any) of this source.
+        :param priority: Optional string parameter to define the priority for the source.
 
         :returns: A dictionary which contains the source.
 
@@ -494,6 +500,8 @@ class SourcesMixin(object):
             data["notify_scheduler"] = notify_scheduler
         if execute_rerun is not None:
             data["execute_rerun"] = execute_rerun
+        if priority is not None:
+            data["priority"] = priority
 
         res = self._perform_request("put", url, data=json.dumps(data), headers=headers)
         return self._process_response(res, [200])
